pub struct World {
pub defaults: WorldDefaults,
pub persons: BTreeMap<StudentNumber, MockPerson>,
pub course_units: BTreeMap<CourseCode, MockCourseUnit>,
pub enrolments: BTreeMap<String, MockEnrolment>,
pub attainments: BTreeMap<String, MockAttainment>,
pub submissions: BTreeMap<String, MockSubmission>,
pub product_tokens: BTreeMap<String, MockProductAccessToken>,
}Expand description
A whole world, as installed under one generation. Indexes are derived from the entities rather than part of it, so a caller cannot desynchronise them.
Fields
defaults: WorldDefaultspersons: BTreeMap<StudentNumber, MockPerson>course_units: BTreeMap<CourseCode, MockCourseUnit>enrolments: BTreeMap<String, MockEnrolment>attainments: BTreeMap<String, MockAttainment>submissions: BTreeMap<String, MockSubmission>product_tokens: BTreeMap<String, MockProductAccessToken>Trait Implementations